==> base-domain-0.0.3-20170213.134207-89-sources.jar: com/thebeastshop/scm/po/Watermark.java <==
package com.thebeastshop.scm.po;

import java.util.Date;

import pers.richard.ormybatis.domain.po.IdPo;

public class Watermark extends IdPo {
	private String code;
	private String name;
	private String smallIcon;
	private String largeIcon;
	private Integer active;
	private Integer createId;
	private Date createTime;
	private Date updateTime;
	
	public Watermark(){}
	
	public final static String
		F_CODE = "CODE",
		F_NAME = "NAME",
		F_SMALL_ICON = "SMALL_ICON",
		F_LARGE_ICON = "LARGE_ICON",
		F_ACTIVE = "ACTIVE",
		F_CREATE_ID = "CREATE_ID",
		F_CREATE_TIME = "CREATE_TIME",
		F_UPDATE_TIME = "UPDATE_TIME";
	

	public String getCode() {return code;}
	public void setCode(String code) {this.code = code;}

	public String getName() {return name;}
	public void setName(String name) {this.name = name;}

	public String getSmallIcon() {return smallIcon;}
	public void setSmallIcon(String smallIcon) {this.smallIcon = smallIcon;}

	public String getLargeIcon() {return largeIcon;}
	public void setLargeIcon(String largeIcon) {this.largeIcon = largeIcon;}

	public Integer getActive() {return active;}
	public void setActive(Integer active) {this.active = active;}

	public Integer getCreateId() {return createId;}
	public void setCreateId(Integer createId) {this.createId = createId;}

	public Date getCreateTime() {return createTime;}
	public void setCreateTime(Date createTime) {this.createTime = createTime;}

	public Date getUpdateTime() {return updateTime;}
	public void setUpdateTime(Date updateTime) {this.updateTime = updateTime;}
}

==> base-domain-1.2.1-sources.jar: com/thebeastshop/scm/po/Watermark.java <==
package com.thebeastshop.scm.po;

import java.util.Date;

import pers.richard.ormybatis.domain.po.IdPo;

public class Watermark extends IdPo {
	private String code;
	private String name;
	private String smallIcon;
	private String largeIcon;
	private String detailNum;
	private Integer active;
	private Integer createId;
	private Date createTime;
	private Date updateTime;
	
	public Watermark(){}
	
	public final static String
		F_CODE = "CODE",
		F_NAME = "NAME",
		F_SMALL_ICON = "SMALL_ICON",
		F_LARGE_ICON = "LARGE_ICON",
		F_ACTIVE = "ACTIVE",
		F_CREATE_ID = "CREATE_ID",
		F_CREATE_TIME = "CREATE_TIME",
		F_UPDATE_TIME = "UPDATE_TIME";
	

	public String getCode() {return code;}
	public void setCode(String code) {this.code = code;}

	public String getName() {return name;}
	public void setName(String name) {this.name = name;}

	public String getSmallIcon() {return smallIcon;}
	public void setSmallIcon(String smallIcon) {this.smallIcon = smallIcon;}

	public String getLargeIcon() {return largeIcon;}
	public void setLargeIcon(String largeIcon) {this.largeIcon = largeIcon;}

	public Integer getActive() {return active;}
	public void setActive(Integer active) {this.active = active;}

	public Integer getCreateId() {return createId;}
	public void setCreateId(Integer createId) {this.createId = createId;}

	public Date getCreateTime() {return createTime;}
	public void setCreateTime(Date createTime) {this.createTime = createTime;}

	public Date getUpdateTime() {return updateTime;}
	public void setUpdateTime(Date updateTime) {this.updateTime = updateTime;}

	public String getDetailNum() {
		return detailNum;
	}

	public void setDetailNum(String detailNum) {
		this.detailNum = detailNum;
	}
}
